#ifdef GL_ES
precision highp float;
#endif

varying vec4 varColor;
varying vec2 varTexCoord;
#ifdef USE_FOG
varying float varFog;
#endif  // USE_FOG
#ifdef USE_ENV
varying vec2 varEnvCoord;
#endif  // USE_ENV

// textures
uniform sampler2D diffuseTexture;

#ifdef ALPHA_TEST
// alpha test
uniform float alphaRef;
#endif  // ALPHA_TEST

#ifdef USE_FOG
// fog vars
uniform bool inFog;
uniform vec3 fogColor;
#endif  // USE_FOG

#ifdef USE_ENV
// env vars
uniform sampler2D envTexture;
uniform bool setEnv;
uniform vec3 envColor;
#endif  // USE_ENV

void main(void)
{
  vec4 diffuse = texture2D(diffuseTexture, varTexCoord);
#ifdef ALPHA_TEST
  if (diffuse.a < alphaRef) {
    discard;
  }
#endif  // ALPHA_TEST
  gl_FragColor = varColor * diffuse;

#ifdef USE_ENV
  if (setEnv) {
    vec3 specular = texture2D(envTexture, varEnvCoord).rgb;
    gl_FragColor.rgb += envColor * specular;
  }
#endif  // USE_ENV

#ifdef USE_FOG
  if (inFog) {
    gl_FragColor.rgb = mix(fogColor, gl_FragColor.rgb, varFog);
  }
#endif  // USE_FOG
}
